@@ -5,12 +5,15 @@ from typing import Text
 
 import click
 from rich.console import Console
+from rich.table import Table
 
 from neuralspace import VERSION
 from neuralspace.apis import get_async_http_session
 from neuralspace.ner.commands import ner
 from neuralspace.nlu.commands import nlu
 from neuralspace.utils import (
+    add_apps_to_table,
+    add_heading_to_description_table,
     app_install,
     do_login,
     print_logo,
@@ -41,6 +44,14 @@ def entrypoint():
     pass
 
 
+@entrypoint.command(name="list-apps")
+def list_apps():
+    table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
+    table = add_heading_to_description_table(table)
+    table = add_apps_to_table(table)
+    console.print(table)
+
+
 @entrypoint.command(name="install-app")
 @click.option(
     "-n",
@@ -54,7 +65,6 @@ def entrypoint():
 )
 def install_app(name: Text, log_level: Text):
     setup_logger(log_level=log_level)
-    print_logo_and_description()
     loop = asyncio.new_event_loop()
     loop.run_until_complete(app_install(name))
     loop.run_until_complete(get_async_http_session().close())
