@@ -18,6 +18,7 @@ from neuralspace.constants import (
     COUNT,
     DATA,
     DEAD,
+    END_INDEX,
     ENTITIES,
     ENTITY_ACC,
     EXAMPLE,
@@ -25,6 +26,7 @@ from neuralspace.constants import (
     EXAMPLES,
     FAILED,
     FILTER,
+    INITIATED,
     INTENT,
     INTENT_ACCURACY,
     INTENT_CLASSIFIER_METRICS,
@@ -46,16 +48,25 @@ from neuralspace.constants import (
     PROJECT_ID,
     PROJECT_NAME,
     PROJECTS,
+    QUEUED,
     REPLICAS,
     SEARCH,
+    START_INDEX,
     TEXT,
     TIMED_OUT,
     TRAINING_STATUS,
     TRAINING_TIME,
     TYPE,
-    neuralspace_url, UPLOAD_DATASET_COMMAND, INITIATED, QUEUED, START_INDEX, END_INDEX,
+    UPLOAD_DATASET_COMMAND,
+    neuralspace_url,
 )
 from neuralspace.nlu.constants import (
+    C_COMPLETED,
+    C_DEAD,
+    C_FAILED,
+    C_INITIATED,
+    C_QUEUED,
+    C_TIMED_OUT,
     CREATE_EXAMPLE_URL,
     CREATE_PROJECT_URL,
     DELETE_EXAMPLE_URL,
@@ -68,7 +79,7 @@ from neuralspace.nlu.constants import (
     LIST_PROJECTS_URL,
     PARSE_URL,
     SINGLE_MODEL_DETAILS_URL,
-    TRAIN_MODEL_URL, C_COMPLETED, C_QUEUED, C_INITIATED, C_DEAD, C_TIMED_OUT, C_FAILED,
+    TRAIN_MODEL_URL,
 )
 from neuralspace.utils import get_auth_token, is_success_status, print_ner_response
 
@@ -77,7 +88,9 @@ console = Console()
 
 
 async def get_languages() -> Dict[Text, Any]:
-    console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ⬇️ Fetching all supported languages for NLU")
+    console.print(
+        "> [deep_sky_blue2]INFO[/deep_sky_blue2] ⬇️ Fetching all supported languages for NLU"
+    )
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
     async with get_async_http_session().get(
@@ -86,11 +99,15 @@ async def get_languages() -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully created project")
+            console.print(
+                "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully created project"
+            )
             console.print(f"{json.dumps(json_response, indent=4)}")
         else:
             logger.error("> [red]ERROR[/red] ❌ Failed to create project")
-            logger.error(f"😔 Platform response: \n{json.dumps(json_response, indent=4)}")
+            logger.error(
+                f"😔 Platform response: \n{json.dumps(json_response, indent=4)}"
+            )
     return json_response
 
 
@@ -150,7 +167,9 @@ async def create_project(project_name: Text, languages: List[Text]) -> Dict[Text
 
 
 async def delete_project(project_id: Text) -> Dict[Text, Any]:
-    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🗑️ Deleting project with id: {project_id}")
+    console.print(
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🗑️ Deleting project with id: {project_id}"
+    )
     payload = {PROJECT_ID: project_id}
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
@@ -161,30 +180,35 @@ async def delete_project(project_id: Text) -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully deleted project")
+            console.print(
+                "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully deleted project"
+            )
         else:
             logger.error("> [red]ERROR[/red] ❌ Failed to delete projects")
-            logger.error(f"😔 Platform response: \n{json.dumps(json_response, indent=4)}")
+            logger.error(
+                f"😔 Platform response: \n{json.dumps(json_response, indent=4)}"
+            )
     return json_response
 
 
-def print_projects_table(projects: Dict[Text, Any]):
+def print_projects_table(projects: Dict[Text, Any], verbose: bool):
     table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
     table.add_column("Project Name", style="#c47900")
     table.add_column("Project ID", style="#c47900")
-    table.add_column("Number of Examples", style="#c47900")
-    table.add_column("Number of Intents", style="#c47900")
-    table.add_column("Number of Models", style="#c47900")
     table.add_column("Languages", style="#c47900")
+    if verbose:
+        table.add_column("Number of Examples", style="#c47900")
+        table.add_column("Number of Intents", style="#c47900")
+        table.add_column("Number of Models", style="#c47900")
     for data in projects[DATA][PROJECTS]:
-        table.add_row(
-                data[PROJECT_NAME],
-                data[PROJECT_ID],
+        args = [data[PROJECT_NAME], data[PROJECT_ID], ", ".join(data[LANGUAGE])]
+        if verbose:
+            args += [
                 str(data[NUMBER_OF_EXAMPLES]),
                 str(data[NUMBER_OF_INTENTS]),
                 str(data[NUMBER_OF_MODELS]),
-                ", ".join(data[LANGUAGE])
-        )
+            ]
+        table.add_row(*args)
     console.print(table)
 
 
@@ -213,7 +237,7 @@ def train_table(projects: Dict[Text, Any]):
 
 
 async def list_projects(
-    search: Text, page_size: int, page_number: int, languages: List[Text]
+    search: Text, page_size: int, page_number: int, languages: List[Text], verbose: bool
 ) -> Dict[Text, Any]:
     payload = {
         SEARCH: search,
@@ -231,28 +255,32 @@ async def list_projects(
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
             console.print(
-                f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 📚 Your projects for Page {page_number} with Page Size: {page_size}"
+                f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 📚 Your projects for Page {page_number} "
+                f"with Page Size: {page_size}"
             )
-            print_projects_table(json_response)
+            print_projects_table(json_response, verbose)
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to list projects")
             console.print(f"Platform response: \n{json.dumps(json_response, indent=4)}")
     return json_response
 
 
-def print_examples_table(examples: Dict[Text, Any]):
+def print_examples_table(examples: Dict[Text, Any], verbose: bool = False):
     table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
     table.add_column("Example ID", style="#c47900")
     table.add_column("Text", style="#c47900")
     table.add_column("Intent", style="#c47900")
-    table.add_column("N Entities", style="#c47900")
+    if verbose:
+        table.add_column("N Entities", style="#c47900")
 
-    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🔢 Total Examples Count: {examples[DATA][COUNT]}")
+    console.print(
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🔢 Total Examples Count: {examples[DATA][COUNT]}"
+    )
     for data in examples[DATA][EXAMPLES]:
-        text = data[TEXT][:20]
-        if len(data[TEXT]) > 20:
-            text = f"{text}..."
-        table.add_row(data[EXAMPLE_ID], text, data[INTENT], len(data[ENTITIES]))
+        args = [data[EXAMPLE_ID], data[TEXT], data[INTENT]]
+        if verbose:
+            args.append(str(len(data[ENTITIES])))
+        table.add_row(*args)
 
     console.print(table)
 
@@ -265,6 +293,7 @@ async def list_examples(
     intent: Text,
     page_number: int,
     page_size: int,
+    verbose: bool = False,
 ) -> Dict[Text, Any]:
     console.print(
         f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⬇️ Fetching Examples with filter: \n"
@@ -295,10 +324,12 @@ async def list_examples(
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            print_examples_table(json_response)
+            print_examples_table(json_response, verbose)
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to list examples")
-            console.print(f"> Platform response: \n{json.dumps(json_response, indent=4)}")
+            console.print(
+                f"> Platform response: \n{json.dumps(json_response, indent=4)}"
+            )
     return json_response
 
 
@@ -317,37 +348,45 @@ def get_training_status_colour(status: Text) -> Text:
         return C_QUEUED
 
 
-def print_models_table(models: Dict[Text, Any]):
+def print_models_table(models: Dict[Text, Any], verbose: bool):
     table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
     table.add_column("Model ID", style="#c47900")
     table.add_column("Model Name", style="#c47900")
     table.add_column("Training Status", style="#c47900")
-    table.add_column("Intent Acc", style="#c47900")
-    table.add_column("Entity Acc", style="#c47900")
-    table.add_column("Training Time (sec)", style="#c47900")
-    table.add_column("Last Updated", style="#c47900")
+    if verbose:
+        table.add_column("Replicas", style="#c47900")
+        table.add_column("Intent Acc", style="#c47900")
+        table.add_column("Entity Acc", style="#c47900")
+        table.add_column("Training Time (sec)", style="#c47900")
+        table.add_column("Last Updated", style="#c47900")
 
     console.print(f"> Total Models Count: {models[DATA][COUNT]}")
-    console.print(f" [deep_sky_blue2]INFO[/deep_sky_blue2] 🔢 Total Models Count: {models[DATA][COUNT]}")
+    console.print(
+        f" [deep_sky_blue2]INFO[/deep_sky_blue2] 🔢 Total Models Count: {models[DATA][COUNT]}"
+    )
     for data in models[DATA][MODELS]:
-        table.add_row(
-
-                data[MODEL_ID],
-                data[MODEL_NAME],
-                f"{get_training_status_colour(data[TRAINING_STATUS])} {data[TRAINING_STATUS]}",
-                data[REPLICAS],
+        args = [
+            data[MODEL_ID],
+            data[MODEL_NAME],
+            f"{get_training_status_colour(data[TRAINING_STATUS])} {data[TRAINING_STATUS]}",
+        ]
+        if verbose:
+            args += [
+                str(data[REPLICAS]),
                 "{:.3f}".format(
                     data[METRICS][INTENT_CLASSIFIER_METRICS][INTENT_ACCURACY]
                 )
                 if data[TRAINING_STATUS] == COMPLETED
-                else 0.0,
+                else "0.0",
                 "{:.3f}".format(data[METRICS][NER_METRICS][ENTITY_ACC])
                 if data[TRAINING_STATUS] == COMPLETED
-                else 0.0,
-                data[TRAINING_TIME] if data[TRAINING_STATUS] == COMPLETED else 0.0,
-                data[LAST_STATUS_UPDATED],
-
-        )
+                else "0.0",
+                str(data[TRAINING_TIME])
+                if data[TRAINING_STATUS] == COMPLETED
+                else "0.0",
+                str(data[LAST_STATUS_UPDATED]),
+            ]
+        table.add_row(*args)
     console.print(table)
 
 
@@ -357,6 +396,7 @@ async def list_models(
     training_status: List[Text],
     page_number: int,
     page_size: int,
+    verbose: bool,
 ) -> Dict[Text, Any]:
     console.print(
         f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⬇️ Fetching models with filter: \n"
@@ -381,15 +421,19 @@ async def list_models(
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            print_models_table(json_response)
+            print_models_table(json_response, verbose)
         else:
             logger.error("> [red]ERROR[/red] ❌ Failed to list models")
-            logger.error(f"> Platform response: \n{json.dumps(json_response, indent=4)}")
+            logger.error(
+                f"> Platform response: \n{json.dumps(json_response, indent=4)}"
+            )
     return json_response
 
 
 async def delete_examples(example_ids: List[Text]) -> Dict[Text, Any]:
-    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🗑️ Deleting Example with id: {example_ids}")
+    console.print(
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🗑️ Deleting Example with id: {example_ids}"
+    )
     payload = {EXAMPLE_ID: example_ids}
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
@@ -400,10 +444,14 @@ async def delete_examples(example_ids: List[Text]) -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully deleted example!")
+            console.print(
+                "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully deleted example!"
+            )
         else:
             logger.error("> [red]ERROR[/red] ❌ Failed to delete examples")
-            logger.error(f"> Platform response: \n{json.dumps(json_response, indent=4)}")
+            logger.error(
+                f"> Platform response: \n{json.dumps(json_response, indent=4)}"
+            )
     return json_response
 
 
@@ -442,7 +490,10 @@ async def upload_dataset(
             if is_success_status(response.status):
                 responses.append(json_response)
             else:
-                console.print(f"> [red]ERROR[/red] ❌ Failed to upload example with text [dark_orange3]{example['text']}[/dark_orange3]")
+                console.print(
+                    f"> [red]ERROR[/red] ❌ Failed to upload example with text "
+                    f"[dark_orange3]{example['text']}[/dark_orange3]"
+                )
                 console.print(
                     f"> Failed on example: \n{json.dumps(example, indent=4, ensure_ascii=False)}"
                 )
@@ -454,11 +505,17 @@ async def upload_dataset(
                     continue
                 else:
                     break
-    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Uploaded {len(responses)} examples")
-    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ❌ Failed on {len(error_examples)} examples")
+    console.print(
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Uploaded {len(responses)} examples"
+    )
+    console.print(
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ❌ Failed on {len(error_examples)} examples"
+    )
     with open("failed_examples.json", "w") as f:
         json.dump(error_examples, f, ensure_ascii=False)
-        console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✍️ Writing failed examples into failed_examples.json")
+        console.print(
+            "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✍️ Writing failed examples into failed_examples.json"
+        )
     return responses
 
 
@@ -545,7 +602,9 @@ async def train_model(
 
 
 async def delete_models(model_id: Text) -> Dict[Text, Any]:
-    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🗑️ Deleting model with id: {model_id}")
+    console.print(
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 🗑️ Deleting model with id: {model_id}"
+    )
     payload = {MODEL_ID: model_id}
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
@@ -556,15 +615,21 @@ async def delete_models(model_id: Text) -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully deleted model")
+            console.print(
+                "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully deleted model"
+            )
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to delete models")
-            console.print(f"> Platform response: \n {json.dumps(json_response, indent=4)}")
+            console.print(
+                f"> Platform response: \n {json.dumps(json_response, indent=4)}"
+            )
     return json_response
 
 
 async def deploy(model_id: Text, n_replicas: int) -> Dict[Text, Any]:
-    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⤴️ Deploying: Model ID: {model_id}; Replicas: {n_replicas};")
+    console.print(
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] ⤴️ Deploying: Model ID: {model_id}; Replicas: {n_replicas};"
+    )
     payload = {MODEL_ID: model_id, N_REPLICAS: n_replicas}
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
@@ -576,11 +641,17 @@ async def deploy(model_id: Text, n_replicas: int) -> Dict[Text, Any]:
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Model deployed successfully")
-            console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Platform Response: \n{json.dumps(json_response, indent=4)}")
+            console.print(
+                "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Model deployed successfully"
+            )
+            console.print(
+                f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Platform Response: \n{json.dumps(json_response, indent=4)}"
+            )
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to deploy model")
-            console.print(f"> Platform response: \n{json.dumps(json_response, indent=4)}")
+            console.print(
+                f"> Platform response: \n{json.dumps(json_response, indent=4)}"
+            )
     return json_response
 
 
@@ -591,22 +662,24 @@ def print_nlu_response(nlu_response: Dict[Text, Any], response_time: float):
     table.add_column("Intent Confidence", style="#c47900")
     table.add_column("Response Time (sec)", style="#c47900")
     table.add_row(
-            nlu_response[DATA]["text"][:30] + "[...]",
-            nlu_response[DATA]["intent"]["name"],
-            nlu_response[DATA]["intent"]["confidence"],
-            str(response_time / 1000),
+        nlu_response[DATA]["text"][:30] + "[...]",
+        nlu_response[DATA]["intent"]["name"],
+        nlu_response[DATA]["intent"]["confidence"],
+        str(response_time / 1000),
     )
     console.print(table)
-    intent_ranking_table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
+    intent_ranking_table = Table(
+        show_header=True, header_style="bold #c47900", show_lines=True
+    )
     table.add_column("Intent", style="#c47900")
     table.add_column("Confidence", style="#c47900")
 
     for row in nlu_response[DATA]["intent_ranking"]:
         intent_ranking_table.add_row(
-                row["name"],
-                row["confidence"],
+            row["name"],
+            row["confidence"],
         )
-    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Intent Ranking")
+    console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] Intent Ranking")
     console.print(intent_ranking_table)
     formatted_entities = []
     for e in nlu_response["data"]["entities"]:
@@ -617,7 +690,9 @@ def print_nlu_response(nlu_response: Dict[Text, Any], response_time: float):
 
 
 async def parse(model_id: Text, input_text: Text) -> Dict[Text, Any]:
-    console.print(f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 📝 Parsing text: {input_text}, using Model ID: {model_id}")
+    console.print(
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] 📝 Parsing text: {input_text}, using Model ID: {model_id}"
+    )
     payload = {MODEL_ID: model_id, DATA: {TEXT: input_text}}
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
@@ -632,9 +707,13 @@ async def parse(model_id: Text, input_text: Text) -> Dict[Text, Any]:
         response_time = (end - start).microseconds
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            console.print("> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully parsed text")
+            console.print(
+                "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully parsed text"
+            )
             print_nlu_response(json_response, response_time)
         else:
             console.print("> [red]ERROR[/red] ❌ Failed to parse model")
-            console.print(f"> Platform response: \n{json.dumps(json_response, indent=4)}")
+            console.print(
+                f"> Platform response: \n{json.dumps(json_response, indent=4)}"
+            )
     return json_response
