@@ -128,6 +128,15 @@ def nlu_delete_project(project_id: Text, log_level: Text):
     default=[],
     help="List of languages. E.g., -L en -L de; You can add multiple languages",
 )
+@click.option(
+    "-v",
+    "--verbose",
+    type=click.BOOL,
+    required=False,
+    default=False,
+    is_flag=True,
+    help="Verbose results",
+)
 @click.option(
     "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
 )
@@ -136,6 +145,7 @@ def nlu_list_projects(
     page_number: int,
     page_size: int,
     language: List[Text],
+    verbose: bool,
     log_level: Text,
 ):
     setup_logger(log_level=log_level)
@@ -143,7 +153,9 @@ def nlu_list_projects(
     if not languages:
         ValueError(f"Languages is mandatory. You can select from {SUPPORTED_LANGUAGES}")
     loop = asyncio.new_event_loop()
-    loop.run_until_complete(list_projects(search, page_size, page_number, languages))
+    loop.run_until_complete(
+        list_projects(search, page_size, page_number, languages, verbose)
+    )
     loop.run_until_complete(get_async_http_session().close())
 
 
@@ -265,6 +277,15 @@ def nlu_upload_dataset(
     default=20,
     help="items per page to fetch",
 )
+@click.option(
+    "-v",
+    "--verbose",
+    type=click.BOOL,
+    required=False,
+    default=False,
+    is_flag=True,
+    help="Verbose results",
+)
 @click.option(
     "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
 )
@@ -276,6 +297,7 @@ def nlu_list_examples(
     intent: Text,
     page_number: int,
     page_size: int,
+    verbose: bool,
     log_level: Text,
 ):
 
@@ -286,7 +308,14 @@ def nlu_list_examples(
     loop = asyncio.new_event_loop()
     loop.run_until_complete(
         list_examples(
-            project_id, language, prepared_flag, type, intent, page_number, page_size
+            project_id,
+            language,
+            prepared_flag,
+            type,
+            intent,
+            page_number,
+            page_size,
+            verbose,
         )
     )
     loop.run_until_complete(get_async_http_session().close())
@@ -443,6 +472,15 @@ def nlu_check_model_status(
     default=20,
     help="items per page to fetch",
 )
+@click.option(
+    "-v",
+    "--verbose",
+    type=click.BOOL,
+    required=False,
+    default=False,
+    is_flag=True,
+    help="Verbose results",
+)
 @click.option(
     "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
 )
@@ -452,6 +490,7 @@ def nlu_list_models(
     training_status: List[Text],
     page_number: int,
     page_size: int,
+    verbose: bool,
     log_level: Text,
 ):
 
@@ -460,7 +499,9 @@ def nlu_list_models(
         training_status = list(training_status)
     loop = asyncio.new_event_loop()
     loop.run_until_complete(
-        list_models(project_id, language, training_status, page_number, page_size)
+        list_models(
+            project_id, language, training_status, page_number, page_size, verbose
+        )
     )
     loop.run_until_complete(get_async_http_session().close())
 
