@@ -95,7 +95,9 @@ async def do_login(email: Text, password: Text):
                 f"⏩  Install an app: [dark_orange3]{INSTALL_APP_COMMAND}[/dark_orange3]"
             )
         else:
-            console.print("> [red]ERROR[/red] ❌ Login failed! Please check your username and password")
+            console.print(
+                "> [red]ERROR[/red] ❌ Login failed! Please check your username and password"
+            )
 
 
 async def app_install(name: Text):
